@@ -13,12 +13,11 @@ Version 0.01
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 =head1 SYNOPSIS
 
-
 list all repository of c9s:
 
     $ gh list c9s
@@ -31,6 +30,10 @@ or:
 
     $ gh clone miyagawa Plack
 
+    $ gh clone gugod Social http
+
+    $ gh clone clkao Web-Hippie ro
+
 clone from read-only uri:
 
     $ gh clone miyagawa/Plack ro 
@@ -49,6 +52,10 @@ to clone all repository of miyagawa:
 
     $ gh cloneall clkao ro  # read-only
 
+to fork project
+
+    $ gh fork clkao AnyMQ
+
 =head1 AUTHOR
 
 Cornelius, C<< <cornelius.howl at gmail.com> >>
